==> nextcloud-13.0.1.tgz: nextcloud/apps/gallery/l10n/he.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "גלריה",
    "There was a problem reading files from this album" : "קיימת בעיה בקריאת הקבצים מאלבום זה",
    "Aborting preview. Could not find the file" : "מבטל תצוגה מקדימה. לא מצליח לאתר את הקובץ",
    "Could not move \"{file}\", target exists" : "לא ניתן להעביר \"{file}\", קובץ מטרה קיים",
    "Could not move \"{file}\"" : "לא ניתן להעביר \"{file}\"",
    "Could not load the description" : "לא ניתן לטעון את התיאור",
    "Could not load the description: " : "לא ניתן לטעון את התיאור:",
    "Copyright" : "זכויות יוצרים",
    "Could not load the copyright notice: " : "לא ניתן לטעון את הודעת זכויות היוצרים:",
    "Copyright notice" : "הודעת זכויות היוצרים",
    "Link to copyright document" : "קישור למסמך זכויות היוצרים",
    "This application may not work properly on your browser." : "היישום עלול לא לעבוד כראוי בדפדפן שלך.",
    "For an improved experience, please install one of the following alternatives" : "לחוויה משופרת, יש להתקין אחת מהחלופות הבאות",
    "Your browser is not supported!" : "הדפדפן שלך אינו נתמך!",
    "please install one of the following alternatives" : "יש להתקין אחת מהחלופות הבאות",
    "Album cannot be shown" : "לא ניתן להציג את האלבום",
    "No media files found" : "לא נמצאו קובצי מדיה",
    "Upload new files via drag and drop or by using the [+] button above" : "העלאת קבצים חדשים באמצעות גרירה ושחרור או באמצעות כפתור ה- [+] מעלה",
    "Configuration error" : "שגיאת הגדרה",
    "New" : "חדש",
    "Hide Album" : "הסתרת אלבום",
    "Could not hide album" : "לא ניתן היה להסתיר את האלבום",
    "Error loading slideshow template" : "שגיאה בטעינת תבנית המצגת",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>שגיאה!</strong> לא ניתן ליצור תצוגה מקדימה לקובץ זה.<br>יש לעבור לשקופית הבאה בזמן הסרת התמונה מהמצגת",
    "Next" : "הבא",
    "Play" : "נגן",
    "Pause" : "השהה",
    "Previous" : "קודם",
    "Close" : "סגירה",
    "Download" : "הורדה",
    "Toggle background" : "מעבר בין רקעים",
    "Delete" : "מחיקה",
    "Share" : "שתף",
    "Could not create file \"{file}\" because it already exists" : "לא ניתן ליצור את הקובץ \"{file}\" כיוון שהוא כבר קיים",
    "Could not create file \"{file}\"" : "לא ניתן ליצור את הקובץ \"{file}\"",
    "\"{name}\" is an invalid file name." : "\"{name}\" הנו שם קובץ לא חוקי.",
    "File name cannot be empty." : "שם קובץ אינו יכול להיות ריק",
    "Upload" : "העלאה",
    "Error" : "שגיאה",
    "Error while sharing" : "שגיאה במהלך השיתוף",
    "Error while unsharing" : "שגיאה במהלך ביטול השיתוף",
    "Error while changing permissions" : "שגיאה במהלך שינוי ההגדרות",
    "Shared with you and the group {group} by {owner}" : "שותף אתך ועם הקבוצה {group} שבבעלות {owner}",
    "Shared with you by {owner}" : "שותף אתך על ידי {owner}",
    "Share with users or groups …" : "שיתוף עם משתמשים או קבוצות...",
    "Share with users, groups or remote users …" : "שיתוף עם משתמשים, קבוצות או משתמשים חצוניים...",
    "Share link" : "קישור לשיתוף",
    "The public link will expire no later than {days} days after it is created" : "הקישור הציבורי יפוג עד {days} ימים לאחר שנוצר",
    "Link" : "קישור",
    "Password protect" : "הגנה בססמה",
    "Password" : "סיסמא",
    "Choose a password for the public link" : "בחירת סיסמא לקישור ציבורי",
    "Allow editing" : "אישור עריכה",
    "Email link to person" : "שליחת קישור בדוא״ל למשתמש",
    "Send" : "שליחה",
    "Set expiration date" : "הגדרת תאריך תפוגה",
    "Expiration" : "תפוגה",
    "Expiration date" : "תאריך התפוגה",
    "An error occured. Please try again" : "אירעה שגיאה. יש לנסות בבקשה שוב",
    "Adding user..." : "הוספת משתמש...",
    "group" : "קבוצה",
    "remote" : "נשלט מרחוק",
    "Resharing is not allowed" : "אסור לעשות שיתוף מחדש",
    "Error while retrieving shares" : "שגיאה במהלך שליפת שיתופים",
    "Unshare" : "הסר שיתוף",
    "notify by email" : "קבלת הודעה בדואר אלקטרוני",
    "can share" : "ניתן לשתף",
    "can edit" : "ניתן לערוך",
    "access control" : "בקרת גישה",
    "create" : "יצירה",
    "change" : "שינוי",
    "delete" : "מחיקה",
    "Password protected" : "מוגן בססמה",
    "Error unsetting expiration date" : "אירעה שגיאה בביטול תאריך התפוגה",
    "Error setting expiration date" : "אירעה שגיאה בעת הגדרת תאריך התפוגה",
    "Email sent" : "הודעת הדוא״ל נשלחה",
    "Warning" : "אזהרה",
    "This share is password-protected" : "שיתוף זה מוגן סיסמא",
    "The password is wrong. Try again." : "הסיסמא שגויה. יש לנסות שנית.",
    "Sort by name" : "מיון על פי שם",
    "Sort by date" : "מיון על פי תאריך",
    "Cancel upload" : "ביטול ההעלאה",
    "Album information" : "פרטי אלבום",
    "File list" : "רשימת קבצים",
    "Sorry, this file could not be found." : "מצטערים, קובץ זה לא אותר.",
    "Reasons might be:" : "הסיבות יכולות להיות:",
    "the wrong file ID was provided" : "סופק מספר מזהה קובץ שגוי",
    "the file was removed" : "הקובץ הוסר",
    "the file is corrupt" : "הקובץ משובש",
    "the encryption key is missing" : "מפתח ההצפנה חסר",
    "Here is the error message returned by the server: " : "להלן הודעת השגיאה שהתקבלה מהשרת:",
    "Sorry, but the server could not fulfill your request." : "מצטערים, אך אין באפשרותו של השרת למלא את בקשתך.",
    "Possible reasons for the problem:" : "סיבות אפשריות לבעיה:",
    "a conflicting app was installed" : "הותקן יישום הגורם להתנגשות",
    "a required component is missing or was disconnected" : "מרכיב נדרש חסר או מנותק",
    "the filesystem is not readable" : "קובץ המערכת לא ניתן לקריאה",
    "Sorry, this link doesn't seem to work anymore." : "מצטערים, לא נראה שקישור זה עובד יותר. ",
    "the item was removed" : "הפריט הוסר",
    "the link has expired" : "הקישור פג תוקף",
    "sharing is disabled" : "השיתוף נוטרל",
    "For more information, please ask the person who has sent you this link." : "למידע נוסף, יש לפנות לשולח קישור זה.",
    "Picture view" : "תצוגת תמונה",
    "Gallery view" : "תצוגת גלריה",
    "Sending ..." : "מתבצעת שליחה ..."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-16.0.5.tgz: nextcloud/apps/gallery/l10n/he.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "גלריה",
    "There was a problem reading files from this album" : "קיימת בעיה בקריאת הקבצים מאלבום זה",
    "Aborting preview. Could not find the file" : "מבטל תצוגה מקדימה. לא מצליח לאתר את הקובץ",
    "Could not move \"{file}\", target exists" : "לא ניתן להעביר \"{file}\", קובץ מטרה קיים",
    "Could not move \"{file}\"" : "לא ניתן להעביר \"{file}\"",
    "No compatible server found at {remote}" : "לא נמצא שרת תואם בכתובת {remote}",
    "Invalid server url" : "כתובת השרת שגויה",
    "Could not load the description" : "לא ניתן לטעון את התיאור",
    "Could not load the description: " : "לא ניתן לטעון את התיאור:",
    "Copyright" : "זכויות יוצרים",
    "Could not load the copyright notice: " : "לא ניתן לטעון את הודעת זכויות היוצרים:",
    "Copyright notice" : "הודעת זכויות היוצרים",
    "Link to copyright document" : "קישור למסמך זכויות היוצרים",
    "This application may not work properly on your browser." : "היישום עלול לא לעבוד כראוי בדפדפן שלך.",
    "For an improved experience, please install one of the following alternatives" : "לחוויה משופרת, יש להתקין אחת מהחלופות הבאות",
    "Your browser is not supported!" : "הדפדפן שלך אינו נתמך!",
    "please install one of the following alternatives" : "יש להתקין אחת מהחלופות הבאות",
    "Album cannot be shown" : "לא ניתן להציג את האלבום",
    "No media files found" : "לא נמצאו קובצי מדיה",
    "Upload pictures in the Files app to display them here" : "ניתן להעלות תמונות ביישומון הקבצים כדי להציג אותם כאן",
    "Upload new files via drag and drop or by using the [+] button above" : "העלאת קבצים חדשים באמצעות גרירה ושחרור או באמצעות כפתור ה- [+] מעלה",
    "Configuration error" : "שגיאת הגדרה",
    "Hide Album" : "הסתרת אלבום",
    "Could not hide album" : "לא ניתן היה להסתיר את האלבום",
    "Error loading slideshow template" : "שגיאה בטעינת תבנית המצגת",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>שגיאה!</strong> לא ניתן ליצור תצוגה מקדימה לקובץ זה.<br>יש לעבור לשקופית הבאה בזמן הסרת התמונה מהמצגת",
    "Next" : "הבא",
    "Play" : "נגן",
    "Pause" : "השהה",
    "Previous" : "קודם",
    "Close" : "סגירה",
    "Download" : "הורדה",
    "Toggle background" : "מעבר בין רקעים",
    "Delete" : "מחיקה",
    "Share" : "שתף",
    "Could not create file \"{file}\" because it already exists" : "לא ניתן ליצור את הקובץ \"{file}\" כיוון שהוא כבר קיים",
    "Could not create file \"{file}\"" : "לא ניתן ליצור את הקובץ \"{file}\"",
    "\"{name}\" is an invalid file name." : "\"{name}\" הנו שם קובץ לא חוקי.",
    "File name cannot be empty." : "שם קובץ אינו יכול להיות ריק",
    "\"{name}\" is not an allowed filetype" : "סוג הקובץ „{name}” אינו מורשה",
    "Upload" : "העלאה",
    "Error" : "שגיאה",
    "Error while sharing" : "שגיאה במהלך השיתוף",
    "Error while unsharing" : "שגיאה במהלך ביטול השיתוף",
    "Error while changing permissions" : "שגיאה במהלך שינוי ההגדרות",
    "Shared with you and the group {group} by {owner}" : "שותף אתך ועם הקבוצה {group} שבבעלות {owner}",
    "Shared with you by {owner}" : "שותף אתך על ידי {owner}",
    "Share with users or groups …" : "שיתוף עם משתמשים או קבוצות...",
    "Share with users, groups or remote users …" : "שיתוף עם משתמשים, קבוצות או משתמשים חצוניים...",
    "Share link" : "קישור לשיתוף",
    "The public link will expire no later than {days} days after it is created" : "הקישור הציבורי יפוג עד {days} ימים לאחר שנוצר",
    "Link" : "קישור",
    "Password protect" : "הגנה בססמה",
    "Password" : "סיסמא",
    "Choose a password for the public link" : "בחירת סיסמא לקישור ציבורי",
    "Allow editing" : "אישור עריכה",
    "Email link to person" : "שליחת קישור בדוא״ל למשתמש",
    "Send" : "שליחה",
    "Set expiration date" : "הגדרת תאריך תפוגה",
    "Expiration" : "תפוגה",
    "Expiration date" : "תאריך התפוגה",
    "This list is maybe truncated - please refine your search term to see more results." : "יכול להיות שהרשימה הזאת אינה מלאה - נא לחדד את החיפוש כדי לצפות בתוצאות נוספות.",
    "No users or groups found for {search}" : "לא נמצאו משתמשים או קבוצות לחיפוש {search}",
    "No users found for {search}" : "לא נמצאו משתמשים לחיפוש {search}",
    "An error occurred (\"{message}\"). Please try again" : "אירעה שגיאה („{message}”). נא לנסות שוב",
    "An error occurred. Please try again" : "אירעה שגיאה. נא לנסות שוב",
    "Adding user..." : "הוספת משתמש...",
    "group" : "קבוצה",
    "remote" : "נשלט מרחוק",
    "Resharing is not allowed" : "אסור לעשות שיתוף מחדש",
    "Error while retrieving shares" : "שגיאה במהלך שליפת שיתופים",
    "Unshare" : "הסר שיתוף",
    "notify by email" : "קבלת הודעה בדואר אלקטרוני",
    "can share" : "ניתן לשתף",
    "can edit" : "ניתן לערוך",
    "access control" : "בקרת גישה",
    "create" : "יצירה",
    "change" : "שינוי",
    "delete" : "מחיקה",
    "Password protected" : "מוגן בססמה",
    "Error unsetting expiration date" : "אירעה שגיאה בביטול תאריך התפוגה",
    "Error setting expiration date" : "אירעה שגיאה בעת הגדרת תאריך התפוגה",
    "Sending…" : "מתבצעת שליחה…",
    "Email sent" : "הודעת הדוא״ל נשלחה",
    "Warning" : "אזהרה",
    "shared by %s" : "שותף על ידי %s",
    "Direct link" : "קישור ישיר",
    "Add to your Nextcloud" : "הוספה ל־Nextcloud שלך",
    "Media gallery for Nextcloud" : "גלריית מדיה ל־Nextcloud",
    "This share is password-protected" : "שיתוף זה מוגן סיסמא",
    "The password is wrong. Try again." : "הסיסמא שגויה. יש לנסות שנית.",
    "Cancel upload" : "ביטול ההעלאה",
    "Sort by name" : "מיון על פי שם",
    "Sort by date" : "מיון על פי תאריך",
    "Album information" : "פרטי אלבום",
    "File list" : "רשימת קבצים",
    "Sorry, this file could not be found." : "מצטערים, קובץ זה לא אותר.",
    "Reasons might be:" : "הסיבות יכולות להיות:",
    "the wrong file ID was provided" : "סופק מספר מזהה קובץ שגוי",
    "the file was removed" : "הקובץ הוסר",
    "the file is corrupt" : "הקובץ משובש",
    "the encryption key is missing" : "מפתח ההצפנה חסר",
    "Here is the error message returned by the server: " : "להלן הודעת השגיאה שהתקבלה מהשרת:",
    "For more information, please contact your friendly Nextcloud administrator." : "למידע נוסף נא ליצור קשר עם מנהל ה־Nextcloud הידידותי שלך.",
    "Sorry, but the server could not fulfill your request." : "מצטערים, אך אין באפשרותו של השרת למלא את בקשתך.",
    "Possible reasons for the problem:" : "סיבות אפשריות לבעיה:",
    "a conflicting app was installed" : "הותקן יישום הגורם להתנגשות",
    "a required component is missing or was disconnected" : "מרכיב נדרש חסר או מנותק",
    "the filesystem is not readable" : "קובץ המערכת לא ניתן לקריאה",
    "Sorry, this link doesn't seem to work anymore." : "מצטערים, לא נראה שקישור זה עובד יותר. ",
    "the item was removed" : "הפריט הוסר",
    "the link has expired" : "הקישור פג תוקף",
    "sharing is disabled" : "השיתוף נוטרל",
    "For more information, please ask the person who has sent you this link." : "למידע נוסף, יש לפנות לשולח קישור זה.",
    "Picture view" : "תצוגת תמונה"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
